@@ -1,5 +1,5 @@
 #' @title Perform the Reductive Early Conservation Test
-#' @description The \emph{Early Conservation Test} has been developed to statistically evaluate the
+#' @description The \emph{Reductive Early Conservation Test} aims to statistically evaluate the
 #' existence of a monotonically increasing phylotranscriptomic pattern based on \code{\link{TAI}} or \code{\link{TDI}} computations.
 #' The corresponding p-value quantifies the probability that a given TAI or TDI pattern (or any phylotranscriptomics pattern) 
 #' does not follow an early conservation like pattern. A p-value < 0.05 indicates that the corresponding phylotranscriptomics pattern does
@@ -17,6 +17,8 @@
 #' @param runs specify the number of runs to be performed for goodness of fit computations, in case \code{plotHistogram} = \code{TRUE}.
 #' In most cases \code{runs} = 100 is a reasonable choice. Default is \code{runs} = 10 (because it takes less computation time for demonstration purposes).
 #' @param parallel performing \code{runs} in parallel (takes all cores of your multicore machine).
+#' @param gof.warning a logical value indicating whether non significant goodness of fit results should be printed as warning. Default is \code{gof.warning = FALSE}.
+#' @param custom.perm.matrix a custom \code{\link{bootMatrix}} (permutation matrix) to perform the underlying test statistic. Default is \code{custom.perm.matrix = NULL}.
 #' @details The \emph{reductive early conservation test} is a permutation test based on the following test statistic. 
 #'
 #' (1) A set of developmental stages is partitioned into three modules - early, mid, and late - based on prior biological knowledge.
@@ -62,12 +64,12 @@
 #' 
 #' @references 
 #' 
-#' Drost et al. (2014), Active maintenance of phylotranscriptomic hourglass patterns in animal and plant embryogenesis.
+#' Drost HG et al. (2015) \emph{Evidence for Active Maintenance of Phylotranscriptomic Hourglass Patterns in Animal and Plant Embryogenesis}. Mol Biol Evol. 32 (5): 1221-1231 doi:10.1093/molbev/msv012.
 #'
-#' Quint M et al. (2012). A transcriptomic hourglass in plant embryogenesis. Nature (490): 98-101.
+#' Quint M et al. (2012). \emph{A transcriptomic hourglass in plant embryogenesis}. Nature (490): 98-101.
 #' 
-#' Piasecka B, Lichocki P, Moretti S, et al. (2013) The hourglass and the early conservation models co-existing
-#' patterns of developmental constraints in vertebrates. PLoS Genet. 9(4): e1003476.
+#' Piasecka B, Lichocki P, Moretti S, et al. (2013) \emph{The hourglass and the early conservation models co-existing
+#' patterns of developmental constraints in vertebrates}. PLoS Genet. 9(4): e1003476.
 #' 
 #' @author Hajk-Georg Drost
 #' @seealso \code{\link{ecScore}}, \code{\link{bootMatrix}}, \code{\link{FlatLineTest}},\code{\link{ReductiveHourglassTest}} , \code{\link{PlotPattern}}
@@ -84,32 +86,40 @@
 #'                        permutations = 1000)
 #'
 #' 
+#' # use your own permutation matrix based on which p-values (EarlyConservationTest)
+#' # shall be computed
+#' custom_perm_matrix <- bootMatrix(PhyloExpressionSetExample,100)
 #' 
-#' 
+#' EarlyConservationTest(PhyloExpressionSetExample,
+#'                        modules = list(early = 1:2, mid = 3:5, late = 6:7), 
+#'                        custom.perm.matrix = custom_perm_matrix)
+#'                        
 #' @import foreach
 #' @export
 
 EarlyConservationTest <- function(ExpressionSet,
-                                  modules       = NULL,
-                                  permutations  = 1000, 
-                                  lillie.test   = FALSE, 
-                                  plotHistogram = FALSE, 
-                                  runs          = 10, 
-                                  parallel      = FALSE){
+                                  modules            = NULL,
+                                  permutations       = 1000, 
+                                  lillie.test        = FALSE, 
+                                  plotHistogram      = FALSE, 
+                                  runs               = 10, 
+                                  parallel           = FALSE,
+                                  gof.warning        = FALSE,
+                                  custom.perm.matrix = NULL){
         
         is.ExpressionSet(ExpressionSet)
         
-        if(length(modules) != 3)
-                stop("Please specify three modules: early, mid, and late to perform the ReductiveHourglassTest.")
-        
-        if(length(unlist(modules)) != (dim(ExpressionSet)[2] - 2))
-                stop("The number of stages classified into the three modules does not match the total number of stages stored in the given ExpressionSet.")
-        
         if(is.null(modules))
                 stop("Please specify the three modules: early, mid, and late using the argument 'module = list(early = ..., mid = ..., late = ...)'.")
         
+        if(length(modules) != 3)
+                stop("Please specify three modules: early, mid, and late to perform the EarlyConservationTest.")
+        
+        if(length(unlist(modules)) != (dim(ExpressionSet)[2] - 2))
+                stop("The number of stages classified into the three modules does not match the total number of stages stored in the given ExpressionSet.")
+        
         if(any(table(unlist(modules)) > 1))
-                stop("Intersecting modules are not defined for the ReductiveHourglassTest.")
+                stop("Intersecting modules are not defined for the EarlyConservationTest.")
         
         nCols <- dim(ExpressionSet)[2]
         score_vector <- vector(mode = "numeric",length = permutations)
@@ -122,9 +132,15 @@ EarlyConservationTest <- function(ExpressionSet,
         real_ecv <- ecScore(real_age,early = modules[[1]],mid = modules[[2]],late = modules[[3]])
                 
         ### compute the bootstrap matrix 
-        resMatrix <- cpp_bootMatrix(as.matrix(ExpressionSet[ , 3:nCols]),as.vector(ExpressionSet[ , 1]),as.numeric(permutations))
+        if (is.null(custom.perm.matrix)){
+                resMatrix <- cpp_bootMatrix(as.matrix(ExpressionSet[ , 3:nCols]),as.vector(ExpressionSet[ , 1]),as.numeric(permutations))
+        }
         
-        ### compute the global phylotranscriptomics destruction scores foe each sampled age vector
+        else if (!is.null(custom.perm.matrix)){
+                resMatrix <- custom.perm.matrix
+        }
+        
+        ### compute the global phylotranscriptomics destruction scores for each sampled age vector
         score_vector <- apply(resMatrix, 1 ,ecScore,early = modules[[1]],
                               mid = modules[[2]],late = modules[[3]])
         
@@ -135,6 +151,10 @@ EarlyConservationTest <- function(ExpressionSet,
         sigma <- param$estimate[2]
         
         if(plotHistogram){
+                
+                if(runs < 1)
+                        stop("You need at least one run...")
+                
                 # plot histogram of scores
                 normDensity <- function(x){
                         
@@ -288,7 +308,7 @@ EarlyConservationTest <- function(ExpressionSet,
                 # does the Lilliefors test pass the criterion
                 lillie_bool <- (lillie_p.val > 0.05)
                 
-                if((lillie_p.val < 0.05) & (!plotHistogram)){
+                if(gof.warning & (lillie_p.val < 0.05) & (!plotHistogram)){
                         warning("Lilliefors (Kolmogorov-Smirnov) test for normality did not pass the p > 0.05 criterion!")
                 }
         }
