@@ -1,4 +1,4 @@
-#' @title Plot the Mean Expression Profiles of Phylostrata or Divergence-Strata
+#' @title Plot the Mean Expression Profiles of Phylostrata or Divergence Strata
 #' @description This function computes for each phylostratum or divergence-stratum the corresponding mean expression profile
 #' and plots the profiles in N different windows corresponding to the given Phylostratum-Classes
 #' that shall be compared.
@@ -86,7 +86,7 @@ PlotMeans <- function(ExpressionSet,Groups = NULL,legendName = NULL,...)
         
         
         # define arguments for different graphics functions
-        plot.args <- c("lwd","col","lty","xlab","cex.lab","main")
+        plot.args <- c("lwd","col","lty","xlab","cex.lab","main","cex.main")
         axis.args <- c("las", "cex.axis")
         legend.args <- c("border","angle","density","box.lwd","cex")
         dots <- list(...)
