@@ -1,16 +1,17 @@
 
-#### Small function to compute the power of a given variable x
 pow <- function(x,power)
 {
   return(x^power)
 }
 
+CollapseFromTo <- function(x,from,to,FUN){  f <- match.fun(FUN); return(apply(x[ , from:to], 1 , f)) }
 
 #' @title Match a Phylostratigraphic Map or Divergence Map with a ExpressionMatrix
 #' @details This function matches a \emph{Phylostratigraphic Map} or \emph{Divergence Map} only storing unique gene ids with a ExpressionMatrix
 #' also storing only unique gene ids.
 #' @param Map a standard \emph{Phylostratigraphic Map} or \emph{Divergence Map} object.
 #' @param ExpressionMatrix  a standard ExpressionMatrix object.
+#' @param remove.duplicates a logical value indicating whether duplicate gene ids should be removed from the data set.
 #' @param accumulate an accumulation function such as \code{mean()}, \code{median()}, or \code{min()}
 #' to accumulate multiple expression levels that map to the same unique gene id present in the \code{ExpressionMatrix}.
 #' @details
@@ -18,7 +19,7 @@ pow <- function(x,power)
 #' In phylotranscriptomics analyses two major techniques are performed to
 #' obtain standard \emph{Phylostratigraphic map} or \emph{Divergence map} objects.
 #' 
-#' To obtain a \emph{Phylostratigraphic Map}, \emph{Phylostratigraphy} (Domazet-Lošo et al., 2007) has to be performed. To obtain a \emph{Divergence Map}, 
+#' To obtain a \emph{Phylostratigraphic Map}, \emph{Phylostratigraphy} (Domazet-Loso et al., 2007) has to be performed. To obtain a \emph{Divergence Map}, 
 #' orthologous gene detection, Ka/Ks computations, and decilation (Quint et al., 2012; Drost et al., 2015) have to be performed.
 #' 
 #' The resulting standard \emph{Phylostratigraphic Map} or \emph{Divergence Map} objects consist of 2 colums storing the phylostratum assignment 
@@ -44,7 +45,7 @@ pow <- function(x,power)
 #' 
 #'   Quint M., Drost H.G., Gabel A., Ullrich K.K., Boenn M., Grosse I. (2012) A transcriptomic hourglass in plant embryogenesis. Nature 490: 98-101.
 #' 
-#'   Drost et al. (2015), Evidence for active maintenance of phylotranscriptomic hourglass patterns in animal and plant embryogenesis.
+#'   Drost HG et al. (2015) \emph{Evidence for Active Maintenance of Phylotranscriptomic Hourglass Patterns in Animal and Plant Embryogenesis}. Mol Biol Evol. 32 (5): 1221-1231 doi:10.1093/molbev/msv012.
 #' 
 #' @author Hajk-Georg Drost
 #' @examples
@@ -87,7 +88,7 @@ pow <- function(x,power)
 #'         
 #'         
 #'@export
-MatchMap <- function(Map,ExpressionMatrix, accumulate = NULL)
+MatchMap <- function(Map,ExpressionMatrix, remove.duplicates = FALSE, accumulate = NULL)
 {
   
   names(ExpressionMatrix)[1] <- "GeneID"
@@ -96,6 +97,9 @@ MatchMap <- function(Map,ExpressionMatrix, accumulate = NULL)
   Map[ , "GeneID"] <- tolower(Map[ , "GeneID"])
   GeneID <- NULL
   
+  if(remove.duplicates)
+          Map <- Map[-which(duplicated(Map[ , "GeneID"])) , ]
+  
   if(any(duplicated(Map[ , "GeneID"])))
           stop("You have duplicate Gene IDs in your Map. Please enter only unique Gene IDs.")
   
@@ -118,20 +122,19 @@ MatchMap <- function(Map,ExpressionMatrix, accumulate = NULL)
           return(res_tbl[ , c(ncol(res_tbl),1:(ncol(res_tbl)-1))])
           
   } else {
-          
-          stop("Something went wrong with matching Map and ExpressionMatrix! Plaese check for duplicate entries!")
+          stop("Something went wrong with matching Map and ExpressionMatrix! Please check for duplicate entries!")
   }
   
 }
 
 
-#' @title Compute TAI or TDI profiles omitting a given gene
+#' @title Compute TAI or TDI Profiles Omitting a Given Gene
 #' @description For each gene i, exclude the corresponding gene i from the global
 #'  PhyloExpressionSet or DivergenceExpressionSet and compute the \code{\link{TAI}} or \code{\link{TDI}} 
 #'  profile for the corresponding global PhyloExpressionSet or DivergenceExpressionSet
 #'  with excluded gene i. 
 #'  
-#'  This results in a TAI or TDI profile Matrix storing the \code{\link{TAI}} or \code{\link{TDI}} profile for each omitted gene i.
+#'  This procedure results in a TAI or TDI profile Matrix storing the TAI or TDI profile for each omitted gene i.
 #' @param ExpressionSet a standard PhyloExpressionSet or DivergenceExpressionSet object.        
 #' @return a numeric matrix storing TAI or TDI profile for each omitted gene i.
 #' @author Hajk-Georg Drost
@@ -230,8 +233,8 @@ re.colors <- function(n)
 #' @description A nice color palette for barplots with several bars.
 #' @param n the number of colors to be in the palette. 
 #' @return a character vector containing different color names that can be used for barplots.
+#' @details This function can be used to select colors for bar plots. 
 #' @author Hajk-Georg Drost
-#' @seealso \code{\link{palette}}
 #' @examples
 #' 
 #' # get 5 different colors for 5 different bars
@@ -246,7 +249,7 @@ bar.colors <- function(n)
 }
 
 
-#' @title Testing the validaty of a PhyloExpressionSet or DivergenceExpressionSet standard
+#' @title Test ExpressionSet Standard
 #' @description This function tests whether a given ExpressionSet follows the pre-defined PhyloExpressionSet or DivergenceExpressionSet standard.
 #' @param ExpressionSet a standard PhyloExpressionSet or DivergenceExpressionSet that shall be tested for format validity.
 #' @author Hajk-Georg Drost
