@@ -1,4 +1,4 @@
-#' @title Compute a permutation matrix for test statistics
+#' @title Compute a Permutation Matrix for Test Statistics
 #' @description This function computes the TAI for a row permutated PhyloExpressionSet or DivergenceExpressionSet.
 #'
 #' One can specify the number of permutations which corresponds to the number of \code{\link{TAI}} or \code{\link{TDI}} profiles
@@ -11,11 +11,14 @@
 #' a given PhyloExpressionSet or DivergenceExpressionSet and computes the corresponding \code{TAI} or \code{TDI} profiles
 #' of the randomly assigned phylostrata or divergence-strata. This sampling is then performed N times, yielding N randomly sampled \code{TAI} or \code{TDI} profiles.
 #' This random \code{TAI} or \code{TDI} profile matrix can then be used to perform statistical tests 
-#' (such as the \code{\link{FlatLineTest}} or \code{\link{ReductiveHourglassTest}}) based on the significance of \code{TAI} or \code{TDI} patterns.
+#' (such as the \code{\link{FlatLineTest}}, \code{\link{ReductiveHourglassTest}}, or \code{\link{EarlyConservationTest}}) based on the significance of \code{TAI} or \code{TDI} patterns.
 #' @return a numeric matrix representing N randomly permuted \code{TAI} or \code{TDI} profiles.
-#' @references Quint M et al. 2012. "A transcriptomic hourglass in plant embryogenesis". Nature (490): 98-101.
+#' @references 
+#' Quint M et al. (2012). \emph{A transcriptomic hourglass in plant embryogenesis}. Nature (490):  98-101.
+#' 
+#' Drost HG et al. (2015). \emph{Evidence for Active Maintenance of Phylotranscriptomic Hourglass Patterns in Animal and Plant Embryogenesis}. Mol Biol Evol. 32 (5): 1221-1231 doi:10.1093/molbev/msv012.
 #' @author Hajk-Georg Drost
-#' @seealso \code{\link{FlatLineTest}}, \code{\link{ReductiveHourglassTest}}
+#' @seealso \code{\link{FlatLineTest}}, \code{\link{ReductiveHourglassTest}}, \code{\link{EarlyConservationTest}}
 #' @examples 
 #' 
 #' # read standard phylotranscriptomics data
@@ -35,7 +38,7 @@ bootMatrix <- function(ExpressionSet,permutations = 1000)
         
         is.ExpressionSet(ExpressionSet)
         
-        nCols <- dim(ExpressionSet)[2]
+        nCols <- ncol(ExpressionSet)
         bootstrapMatrix <- matrix(NA_real_, permutations, (nCols - 2))
         ExprSet <- as.matrix(ExpressionSet[ , 3:nCols])
         AgeVector <- as.vector(ExpressionSet[ , 1])
@@ -47,4 +50,5 @@ bootMatrix <- function(ExpressionSet,permutations = 1000)
         return(bootstrapMatrix)
         
         
-}
\ No newline at end of file
+}
+
